@@ -133,6 +133,7 @@ panel.3dscatter <-
              lwd = if (is.null(groups)) plot.line$lwd else superpose.line$lwd,
              cex = if (is.null(groups)) plot.symbol$cex else superpose.symbol$cex,
              pch = if (is.null(groups)) "+" else superpose.symbol$pch,
+             fill = if (is.null(groups)) plot.symbol$fill else superpose.symbol$fill,
              cross,
              ...,
              .scale = FALSE,
@@ -172,6 +173,7 @@ panel.3dscatter <-
             lwd <- rep(lwd, length.out = n)
             cex <- rep(cex, length.out = n)
             pch <- rep(pch, length.out = n)
+            fill <- rep(fill, length.out = n)
         }
         else
         {
@@ -184,6 +186,7 @@ panel.3dscatter <-
             lwd <- rep(lwd, length.out = nvals)[groups]
             cex <- rep(cex, length.out = nvals)[groups]
             pch <- rep(pch, length.out = nvals)[groups]
+            fill <- rep(fill, length.out = nvals)[groups]
         }
 
 
@@ -229,7 +232,9 @@ panel.3dscatter <-
                 lpoints(x = m[1, ord], y = m[2, ord],
                         col = col.point[ord],
                         pch = pch[ord],
-                        cex = cex[ord], ...,
+                        cex = cex[ord],
+                        fill = fill[ord],
+                        ...,
                         identifier = identifier)
             }
         }
@@ -246,7 +251,7 @@ panel.3dscatter <-
             tmpz0 <- z[ord][-1]
             tmpz1 <- z[ord][-tmplen]
             tmpcol0 <- col.line[ord][-1]
-            tmpcol1 <- col.line[ord][-tmplen]
+            ## tmpcol1 <- col.line[ord][-tmplen]
 
             ## segments shouldn't join points in different groups 
             tmpcol0[ groups[ord][-1] != groups[ord][-tmplen] ] <- "transparent"
@@ -447,7 +452,6 @@ panel.3dwire <-
         gridpolycount <- 0 
 
         wirePolygon <-
-
             function(xx, yy, misc)
             {
 
@@ -487,7 +491,7 @@ panel.3dwire <-
                 }
             }
 
-
+        force(wirePolygon)
         .Call(wireframePanelCalculations,
               as.double(x),
               as.double(y),
@@ -556,7 +560,6 @@ panel.3dwire <-
         gridpolycount <- 0 
 
         wirePolygon <-
-
             function(xx, yy, misc)
             {
                 ## misc:
@@ -605,6 +608,7 @@ panel.3dwire <-
             }
 
 
+        force(wirePolygon)
         .Call(wireframePanelCalculations,
               as.double(x),
               as.double(y),
@@ -641,14 +645,6 @@ panel.3dwire <-
 
 
 
-
-
-
-
-
-
-
-
 panel.cloud <-
     function(x, y, subscripts, z,
              groups = NULL,
@@ -931,7 +927,7 @@ panel.cloud <-
 
         ## box ranges and lengths
         cmin <- lapply(corners, min)
-        cmax <- lapply(corners, max)
+        ## cmax <- lapply(corners, max)
         clen <- lapply(corners, function(x) diff(range(x, finite = TRUE)))
 
 
@@ -1103,7 +1099,7 @@ panel.cloud <-
                 ## can be NA. Needs a lot of change otherwise
 
                 vals <- sort(unique(groups))
-                nvals <- length(vals)
+                ## nvals <- length(vals)
                 tmp <- numeric(0)
 
                 for (i in seq_along(vals)) {
@@ -1136,7 +1132,7 @@ panel.cloud <-
 
             if (!("..." %in% names(formals(panel.3d.wireframe))))
                 pargs <- pargs[intersect(names(pargs), names(formals(panel.3d.wireframe)))]
-            do.call("panel.3d.wireframe", pargs)
+            do.call(panel.3d.wireframe, pargs, quote = TRUE)
         }
         else
         {
@@ -1156,7 +1152,7 @@ panel.cloud <-
                           ...)
             if (!("..." %in% names(formals(panel.3d.cloud))))
                 pargs <- pargs[intersect(names(pargs), names(formals(panel.3d.cloud)))]
-            do.call("panel.3d.cloud", pargs)
+            do.call(panel.3d.cloud, pargs, quote = TRUE)
         }
 
         ## This draws the front of the bounding box
@@ -1180,10 +1176,10 @@ panel.cloud <-
             if (is.logical(scales.3d$x.scales$col.line)) axis.line$col
             else scales.3d$x.scales$col.line
         xaxis.lty <-
-            if (is.logical(scales.3d$x.scales$lty)) axis.line$lwd
+            if (is.logical(scales.3d$x.scales$lty)) axis.line$lty
             else scales.3d$x.scales$lty
         xaxis.lwd <-
-            if (is.logical(scales.3d$x.scales$lwd)) axis.line$lty
+            if (is.logical(scales.3d$x.scales$lwd)) axis.line$lwd
             else scales.3d$x.scales$lwd
         xaxis.col.text <-
             if (is.logical(scales.3d$x.scales$col)) axis.text$col
@@ -1209,10 +1205,10 @@ panel.cloud <-
             if (is.logical(scales.3d$y.scales$col.line)) axis.line$col
             else scales.3d$y.scales$col.line
         yaxis.lty <-
-            if (is.logical(scales.3d$y.scales$lty)) axis.line$lwd
+            if (is.logical(scales.3d$y.scales$lty)) axis.line$lty
             else scales.3d$y.scales$lty
         yaxis.lwd <-
-            if (is.logical(scales.3d$y.scales$lwd)) axis.line$lty
+            if (is.logical(scales.3d$y.scales$lwd)) axis.line$lwd
             else scales.3d$y.scales$lwd
         yaxis.col.text <-
             if (is.logical(scales.3d$y.scales$col)) axis.text$col
@@ -1238,10 +1234,10 @@ panel.cloud <-
             if (is.logical(scales.3d$z.scales$col.line)) axis.line$col
             else scales.3d$z.scales$col.line
         zaxis.lty <-
-            if (is.logical(scales.3d$z.scales$lty)) axis.line$lwd
+            if (is.logical(scales.3d$z.scales$lty)) axis.line$lty
             else scales.3d$z.scales$lty
         zaxis.lwd <-
-            if (is.logical(scales.3d$z.scales$lwd)) axis.line$lty
+            if (is.logical(scales.3d$z.scales$lwd)) axis.line$lwd
             else scales.3d$z.scales$lwd
         zaxis.col.text <-
             if (is.logical(scales.3d$z.scales$col)) axis.text$col
@@ -1666,7 +1662,7 @@ cloud.formula <-
     ## less complicated components:
 
     foo <-
-        do.call("trellis.skeleton",
+        do.call(trellis.skeleton,
                 c(list(formula = formula, 
                        cond = cond,
                        aspect = panel.aspect,
@@ -1674,7 +1670,8 @@ cloud.formula <-
                        panel = panel,
                        xlab = NULL,
                        ylab = NULL,
-                       lattice.options = lattice.options), dots))
+                       lattice.options = lattice.options), dots),
+                quote = TRUE)
 
     ##----------------------------------------------------------------+
     ## xlab, ylab, zlab have special meaning in cloud / wireframe, and|
@@ -1688,7 +1685,7 @@ cloud.formula <-
 
     ## Step 2: Compute scales.common (leaving out limits for now)
 
-    foo <- c(foo, do.call("construct.scales", list(draw=FALSE)))
+    foo <- c(foo, do.call(construct.scales, list(draw=FALSE)))
 
     ## scales has to be interpreted differently. Nothing needs to be
     ## done for the usual scales, but need a scales for panel.cloud
@@ -1696,7 +1693,7 @@ cloud.formula <-
     ## no reason not to allow that (will not allow limits, though)
 
     scales <- updateList(default.scales, scales)
-    scales.3d <- do.call("construct.3d.scales", scales)
+    scales.3d <- do.call(construct.3d.scales, scales)
 
 
     ## Step 3: Decide if limits were specified in call
