@@ -267,7 +267,7 @@ panel.identify.cloud <-
     zlim.scaled <- range(corners$z)
     ## box ranges and lengths
     cmin <- lapply(corners, min)
-    cmax <- lapply(corners, max)
+    ## cmax <- lapply(corners, max)
     clen <- lapply(corners, function(x) diff(range(x, finite = TRUE)))
     ## scaled (to bounding box) data
     x <- cmin$x + clen$x * (x-xlim[1])/diff(xlim)
@@ -292,8 +292,9 @@ panel.identify.cloud <-
 trellis.vpname <-
     function(name = 
              c("position", "split", "split.location", "toplevel", "figure",
-               "panel", "strip", "strip.left", "legend", "main", "sub",
-               "xlab", "ylab", "xlab.top", "ylab.right", "page"),
+               "panel", "strip", "strip.left", "legend", "legend.region",
+               "main", "sub", "xlab", "ylab", "xlab.top", "ylab.right",
+               "page"),
              column = lattice.getStatus("current.focus.column", prefix = prefix),
              row = lattice.getStatus("current.focus.row", prefix = prefix),
              side = c("left", "top", "right", "bottom", "inside"),
@@ -331,28 +332,46 @@ trellis.vpname <-
                  if (clip.off) paste("strip.left", column, row, "off", "vp", sep = ".")
                  else paste("strip.left", column, row, "vp", sep = "."), 
 
-                 legend = paste("legend", side, "vp", sep = ".")),
+                 legend = paste("legend", side, "vp", sep = "."),
+                 legend.region = "legend.region.vp"),
           sep = ".")
 }
 
 
 
 trellis.grobname <-
-    function(name, type = c("", "panel", "strip", "strip.left"),
+    function(name,
+             type = c("", "panel", "strip", "strip.left", "key", "colorkey"),
              group = 0,
+             which.given = lattice.getStatus("current.which.given",
+               prefix = prefix),
+             which.panel = lattice.getStatus("current.which.panel",
+               prefix = prefix),
              column = lattice.getStatus("current.focus.column",
                prefix = prefix),
              row = lattice.getStatus("current.focus.row",
                prefix = prefix),
              prefix = lattice.getStatus("current.prefix"))
 {
+    stripname <- function(striplab,
+                          name, column, row, which.given, which.panel) {
+        if (length(which.panel) > 1) {
+            paste(name, "given", which.given, striplab, 
+                  column, row, sep=".")            
+        } else {
+            paste(name, striplab, column, row, sep=".")
+        }
+    }
     if (group > 0)
         name <- paste(name, "group", group, sep=".")
     paste(prefix,
           switch(type,
-                 panel=paste(name, "panel", column, row, sep="."),
-                 strip=paste(name, "strip", column, row, sep="."),
-                 strip.left=paste(name, "strip.left", column, row, sep="."),
+                 panel=paste(name, type, column, row, sep="."),
+                 strip=,
+                 strip.left=stripname(type, name, column, row,
+                   which.given, which.panel),
+                 key=,
+                 colorkey=paste(type, name, sep="."),
                  name),
           sep = ".")
 }
